@@ -363,8 +363,8 @@ void StatusHandler::receive(DDF& in, ostream& out)
     // Wrap a response shim.
     DDF ret(nullptr);
     DDFJanitor jout(ret);
-    scoped_ptr<HTTPRequest> req(getRequest(in));
-    scoped_ptr<HTTPResponse> resp(getResponse(ret));
+    scoped_ptr<HTTPRequest> req(getRequest(*app, in));
+    scoped_ptr<HTTPResponse> resp(getResponse(*app, ret));
 
     // Since we're remoted, the result should either be a throw, a false/0 return,
     // which we just return as an empty structure, or a response/redirect,
@@ -494,6 +494,7 @@ pair<bool,long> StatusHandler::processMessage(
 
 #ifdef WIN32
 typedef void (WINAPI *PGNSI)(LPSYSTEM_INFO);
+typedef BOOL (WINAPI *PGVEA)(LPOSVERSIONINFOA);
 #endif
 
 ostream& StatusHandler::systemInfo(ostream& os) const
@@ -518,7 +519,8 @@ ostream& StatusHandler::systemInfo(ostream& os) const
     OSVERSIONINFOEX osvi;
     memset(&osvi, 0, sizeof(OSVERSIONINFOEX));
     osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
-    if(GetVersionEx((OSVERSIONINFO*)&osvi)) {
+    PGVEA pGVEA = (PGVEA)GetProcAddress(GetModuleHandle(TEXT("kernel32.dll")), "GetVersionExA");
+    if(pGVEA && pGVEA((OSVERSIONINFO*)&osvi)) {
         os << "<Windows"
            << " version='" << osvi.dwMajorVersion << "." << osvi.dwMinorVersion << "'"
            << " build='" << osvi.dwBuildNumber << "'";
@@ -563,6 +565,9 @@ ostream& StatusHandler::systemInfo(ostream& os) const
 
         os << "/>";
     }
+    else {
+	os << "<Windows/>";
+    }
 #endif
     return os;
 }
